@@ -11,18 +11,14 @@ from sqlalchemy.ext.declarative import as_declarative, declarative_base, declare
 from sqlalchemy.ext.declarative.api import DeclarativeMeta
 from sqlalchemy.orm import scoped_session, sessionmaker
 from flask.ext.sqlalchemy import SQLAlchemy, _BoundDeclarativeMeta
-import sqlalchemy as db
+from sqlalchemy import UniqueConstraint,Column,Integer,Text,String,Date,DateTime,ForeignKey,func,create_engine
+
+get_engine = lambda: create_engine(current_app.config['SQLALCHEMY_DATABASE_URI'])
+Session = lambda: scoped_session(sessionmaker(bind=get_engine()))
 
 Model = declarative_base()
 
 
-def session(engine):
-    return scoped_session(
-                sessionmaker(
-                    bind=engine
-                )
-            )
-
 class SQLAlchemyMissingException(Exception):
     pass
 
@@ -31,16 +27,24 @@ class ModelDeclarativeMeta(_BoundDeclarativeMeta):
 
 @as_declarative(name='BaseMixin',metaclass=ModelDeclarativeMeta)
 class BaseMixin(Model):
-    _session = session()
-    _engine = None
     __abstract__ = True
+    _session = None
 
 
     @property
-    def db_uri(self):
-        import os
-        return os.environ.get('DATABASE_URI',False) or 'sqlite:///tmp.db'
-    
+    def _engine(self):
+        return get_engine()
+
+    @declared_attr
+    def id(self):
+        return Column(Integer,primary_key=True)
+
+    @classmethod
+    def get_session(cls):
+        if cls._session is None:
+            cls._session = Session()
+        return cls._session
+
     @staticmethod
     def make_table_name(name):
         return underscore(pluralize(name))
@@ -48,15 +52,7 @@ class BaseMixin(Model):
     @declared_attr
     def __tablename__(self):
         return BaseMixin.make_table_name(self.__name__)
-
-    @property
-    def query(self):
-        return self._session.query(self)
-
-    @declared_attr
-    def id(self):
-        return db.Column(db.Integer,db.Sequence('user_id_seq'),primary_key=True)
-
+    
     @classmethod
     def get_by_id(cls, id):
         if any(
@@ -70,11 +66,6 @@ class BaseMixin(Model):
     def get_all(cls):
         return cls.query.all()
 
-
-    @property
-    def engine(self):
-        return self._engine or db.create_engine(self.db_uri)
-
     @classmethod
     def create(cls, **kwargs):
         instance = cls(**kwargs)
@@ -87,20 +78,20 @@ class BaseMixin(Model):
 
     def save(self, commit=True):
         try:
-            self._session.add(self)
+            self.session.add(self)
             if commit:
-                self._session.commit()
+                self.session.commit()
         except:
             return False
         return self
 
     def delete(self, commit=True):
-        self._session.delete(self)
-        return commit and self._session.commit()
+        self.session.delete(self)
+        return commit and self.session.commit()
 
     @classmethod
     def query(cls):
-        return cls._session.query(cls)
+        return cls.get_session().query(cls)
 
     @property
     def absolute_url(self):
